@@ -24,61 +24,48 @@ def get_dict_from_instruction(instructions):
     return new_instructions
 class InstructionManager:
     def __init__(self,instructions=None,instruction_bools={})->None:
-        self.default_instructions = json.loads("""
-{
-    "api_response": {
-        "instruction": "Place response to prompt here.",
-        "example": "This is the reply to your request.",
-        "default": true
-    },
-    "additional_responses": {
-        "instruction": "Marking 'True' initiates a loop which continues to send the current chunk's prompt until the module returns a 'False' value.",
-        "example": "false",
-        "default": false
-    },
-    "generate_title": {
-        "instruction": "Generate a short and concise title for this query, using underscores instead of spaces and avoiding special characters. The title should not exceed 200 characters to ensure compatibility with file systems.",
-        "example": "Short_Title_for_Query",
-        "default": true
-    },
-    "database_query": {
-        "instruction": "The given database schema, variables, values, and function are provided in the prompt data; please derive the most appropriate inputs for a database query from the context and assertions of the request. Always include a 'query' key containing the SQL query as a string. Example: {\"query\": \"SELECT * FROM table WHERE condition\"}. Ensure that the 'query' key is always present in the database_query object, and the query is valid SQL.",
-        "example": {"query": "SELECT dnc_data FROM dncdata WHERE dnc_data ->> 'Data_Subscriber_First_Name' = 'Karen';"},
-        "default": false
-    },
-    "notation": {
-        "instruction": "Notation is a module functionality that allows the module, you, to preserve relevant information or context for subsequent prompts; allowing for communication between modules throughout the query iterations.",
-        "example": "Selecting additional responses due to insufficient completion tokens.",
-        "default": false
-    },
-    "suggestions": {
-        "instruction": "This parameter allows the module to provide suggestions for improving efficiency in future prompt sequences.",
-        "example": "Consider batching queries to reduce server load",
-        "default": false
-    },
-    "abort": {
-        "instruction": "If you cannot fulfill the request, respond with this value as 'True'. Leave a detailed reason as to why the query stream was aborted in 'suggestions'.",
-        "example": "False",
-        "default": false
-    },
-    "prompt_as_previous": {
-        "instruction": "This is a user-end declaration. If this is visible, the request portion of the prompt will change to include previous response data, if needed.",
-        "example": "True",
-        "default": false
-    },
-    "request_chunks": {
-        "instruction": "Request to prompt again the previous chunk data. If selected, the query will iterate once more with the previous data chunk included in the prompt.",
-        "example": "False",
-        "default": false
-    },
-    "token_adjustment": {
-        "instruction": "Suggest percentage adjustments, between -100 up to 100, for the future token allotment. If it will provide better results to increase or decrease the future allotment, place a number.",
-        "example": "0",
-        "default": false
-    }
-}
-""")
-
+        self.default_instructions = {
+                    "api_response": {
+                        "instruction": "Place response to prompt here.",
+                        "example": "This is the reply to your request.",
+                        "default":True},
+                    "additional_responses": {
+                        "instruction": "Marking 'True' initiates a loop which continues to send the current chunk's prompt until the module returns a 'False' value.",
+                        "example": "false",
+                        "default":False},
+                    "generate_title": {
+                        "instruction": "Generate a short and concise title for this query, using underscores instead of spaces and avoiding special characters. The title should not exceed 200 characters to ensure compatibility with file systems.",
+                        "example": "Short_Title_for_Query",
+                        "default":True},
+                    "database_query":{
+                        "instruction": "the given database Schema,variables,values and function are provided in the prompt data; please derive the most appropriate inputs for a database query from the context and assertons of the request. place all inputs for the function within this respons key",
+                        "example": {"query":"""SELECT dnc_data FROM dncdata WHERE dnc_data ->> 'Data_Subscriber_First_Name' = 'Karen';"""},
+                        "default":False},
+                    "notation": {
+                        "instruction": "notation is a module end  functionality that allows the module, you, to to preserve relevant information or context for subsequent prompts; allowing for communication between modules throughout the query iterations. ",
+                        "example": "Selecting additional responses due to insufficient completion tokens.",
+                        "default":False},
+                    "suggestions": {
+                        "instruction": "This parameter allows the module to provide suggestions for improving efficiency in future prompt sequences.",
+                        "example": "Consider batching queries to reduce server load",
+                        "default":False},
+                    "abort": {
+                        "instruction": "If you cannot fulfill the request, respond with this value as 'True'. Leave a detailed reason as to why the query stream was aborted in 'suggestions'",
+                        "example": "False",
+                        "default":False},
+                    "prompt_as_previous": {
+                        "instruction": "This is a user-end declaration. If this is visible, the request portion of the prompt will change to include previous response data, if needed",
+                        "example": "True",
+                        "default":False},
+                    "request_chunks": {
+                        "instruction": "Request to prompt again the previous chunk data. If selected, the query will iterate once more with the previous data chunk included in the prompt.",
+                        "example": "False",
+                        "default":False},
+                    "token_adjustment": {
+                        "instruction": "Suggest percentage adjustments, between -100 up to 100, for the future token allotment. If it will provide better results to increase or decrease the future allotment, place a number.",
+                        "example": "0",
+                        "default":False},
+                    }
         self.instructions = [[]]
         self.default_instructions.update(get_dict_from_instruction(instructions))
         for key,value in instruction_bools.items():
