@@ -411,7 +411,7 @@ class PromptManager:
             total_chunks+=len(each)
         chunk_token_distribution_data=self.chunk_token_distributions[chunk_token_distribution_number][chunk_number]
         
-        self.prompt =self.create_prompt_guide(request=self.request_data[chunk_token_distribution_number].replace('n**n','\n'),
+        self.prompt =self.create_prompt_guide(request=self.request_data[chunk_token_distribution_number].replace('*n*','\n'),
                                               instructions=instructions or self.instruction_data[chunk_token_distribution_number]['text'],
                                               chunk_token_distribution_number=chunk_token_distribution_number,
                                               chunk_number=chunk_number,
@@ -421,7 +421,7 @@ class PromptManager:
                                               generate_title=generate_title,
                                               request_chunks=request_chunks,
                                               prompt_as_previous=prompt_as_previous)    
-        max_tokens = self.model_mgr.selected_max_tokens -num_tokens_from_string(str({"model": self.model_mgr.selected_model_name, "messages": [{"role": self.role or "user", "content":self.prompt.replace('n**n','\n') }]}))
+        max_tokens = self.model_mgr.selected_max_tokens -num_tokens_from_string(str({"model": self.model_mgr.selected_model_name, "messages": [{"role": self.role or "user", "content":self.prompt.replace('*n*','\n') }]}))
         self.prompt ={"model": self.model_mgr.selected_model_name, "messages": [{"role": self.role or "user", "content":self.prompt }],"max_tokens": max_tokens}
         blank = True
         for key in self.key_check:
